from PIL import Image
import settings

cdef int maxThreshold = settings.maxThreshold
cdef int maxIteration = settings.maxIteration
cdef int maxI = settings.maxI
cdef int maxJ = settings.maxJ
cdef float deltaX = settings.deltaX
cdef float deltaY = settings.deltaY
im = Image.new("RGB", (maxI,maxJ))

cdef float CalcMandelbrot(float r,float i):
	cdef:
		float zi = 0.0
		float zr = 0.0
		int itercount = 0
		float maxit = maxIteration
		float temp
		float zr2
		float zi2
 
	while(1) :
		itercount += 1
		temp = zr * zi
		zr2 = zr * zr
		zi2 = zi * zi
		zr = zr2 - zi2 + r
		zi = temp + temp + i
		if (zi2 + zr2 > maxThreshold):
			return  256*itercount/maxit
		if (itercount > maxIteration):
			return  1.0
	return 1


cdef int SetZ(int i, int j, int xinc, int yinc):
	cdef: 
		float zr
		float zi
		float zcolor
		
	zr =  -1.0*deltaX/2.0 + xinc * i
	zi =   1.0*deltaY/2.0 - yinc * j
	zcolor = CalcMandelbrot(zr, zi) /1.0001
	return int(zcolor)


def Mandelbrot():
	
	xinc = deltaX/(maxI-1)
	yinc = deltaY/(maxJ-1)
	for  i in range(maxI):
		for j in range(maxJ):
			zcolor = SetZ(i, j, xinc, yinc)
			im.putpixel((i,j),(zcolor,zcolor,zcolor))
	im.save("mandelbrot.png","PNG")
